@@ -23,6 +23,7 @@ from openstack.compute.v2 import limits
 from openstack.compute.v2 import migration as _migration
 from openstack.compute.v2 import quota_set as _quota_set
 from openstack.compute.v2 import server as _server
+from openstack.compute.v2 import server_action as _server_action
 from openstack.compute.v2 import server_diagnostics as _server_diagnostics
 from openstack.compute.v2 import server_group as _server_group
 from openstack.compute.v2 import server_interface as _server_interface
@@ -122,9 +123,9 @@ class Proxy(proxy.Proxy):
     def update_flavor(self, flavor, **attrs):
         """Update a flavor
 
-        :param server: Either the ID of a flavot or a
+        :param flavor: Either the ID of a flavor or a
             :class:`~openstack.compute.v2.flavor.Flavor` instance.
-        :attrs kwargs: The attributes to update on the flavor represented
+        :param attrs: The attributes to update on the flavor represented
             by ``flavor``.
 
         :returns: The updated flavor
@@ -321,9 +322,8 @@ class Proxy(proxy.Proxy):
         """Update a host aggregate
 
         :param server: Either the ID of a host aggregate or a
-            :class:`~openstack.compute.v2.aggregate.Aggregate`
-            instance.
-        :attrs kwargs: The attributes to update on the aggregate represented
+            :class:`~openstack.compute.v2.aggregate.Aggregate` instance.
+        :param attrs: The attributes to update on the aggregate represented
             by ``aggregate``.
 
         :returns: The updated aggregate
@@ -697,7 +697,7 @@ class Proxy(proxy.Proxy):
 
         :param server: Either the ID of a server or a
             :class:`~openstack.compute.v2.server.Server` instance.
-        :attrs kwargs: The attributes to update on the server represented
+        :param attrs: The attributes to update on the server represented
             by ``server``.
 
         :returns: The updated server
@@ -1543,9 +1543,9 @@ class Proxy(proxy.Proxy):
     def update_service(self, service, **attrs):
         """Update a service
 
-        :param server: Either the ID of a service or a
+        :param service: Either the ID of a service or a
             :class:`~openstack.compute.v2.service.Service` instance.
-        :attrs kwargs: The attributes to update on the service represented
+        :param attrs: The attributes to update on the service represented
             by ``service``.
 
         :returns: The updated service
@@ -2000,7 +2000,7 @@ class Proxy(proxy.Proxy):
         :param quota_set: Either the ID of a quota_set or a
             :class:`~openstack.compute.v2.quota_set.QuotaSet` instance.
         :param dict query: Optional parameters to be used with update call.
-        :attrs kwargs: The attributes to update on the QuotaSet represented
+        :params attrs: The attributes to update on the QuotaSet represented
             by ``quota_set``.
 
         :returns: The updated QuotaSet
@@ -2011,6 +2011,49 @@ class Proxy(proxy.Proxy):
             query = {}
         return res.commit(self, **query)
 
+    # ========== Server actions ==========
+
+    def get_server_action(self, server_action, server, ignore_missing=True):
+        """Get a single server action
+
+        :param server_action: The value can be the ID of a server action or a
+            :class:`~openstack.compute.v2.server_action.ServerAction` instance.
+        :param server: This parameter need to be specified when ServerAction ID
+            is given as value. It can be either the ID of a server or a
+            :class:`~openstack.compute.v2.server.Server` instance that the
+            action is associated with.
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
+            the server action does not exist. When set to ``True``, no
+            exception will be set when attempting to retrieve a non-existent
+            server action.
+
+        :returns: One :class:`~openstack.compute.v2.server_action.ServerAction`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound` when no
+            resource can be found.
+        """
+        server_id = self._get_uri_attribute(server_action, server, 'server_id')
+        server_action = resource.Resource._get_id(server_action)
+
+        return self._get(
+            _server_action.ServerAction,
+            server_id=server_id,
+            action_id=server_action,
+            ignore_missing=ignore_missing,
+        )
+
+    def server_actions(self, server):
+        """Return a generator of server actions
+
+        :param server: The server can be either the ID of a server or a
+            :class:`~openstack.compute.v2.server.Server`.
+
+        :returns: A generator of ServerAction objects
+        :rtype: :class:`~openstack.compute.v2.server_action.ServerAction`
+        """
+        server_id = resource.Resource._get_id(server)
+        return self._list(_server_action.ServerAction, server_id=server_id)
+
     # ========== Utilities ==========
 
     def wait_for_server(
